adminify

package module
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 30, 2024 License: MIT Imports: 5 Imported by: 0

README

adminify

A simple, customizable admin panel for Go projects inspired by Django's admin interface.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Adminify

type Adminify struct {
	Panel *admin.Panel
}

func NewAdminify

func NewAdminify(db *sql.DB, driver, path string) Adminify

func (*Adminify) RegisterGinRoute added in v0.0.2

func (a *Adminify) RegisterGinRoute(r *gin.Engine)

RegisterGinRoute registers the admin panel to a Gin route

func (*Adminify) RegisterModel

func (a *Adminify) RegisterModel(modelStruct interface{}, tableName string)

func (*Adminify) ServeHTTP

func (a *Adminify) ServeHTTP(w http.ResponseWriter, r *http.Request)

Directories

Path Synopsis
internal
pkg

Jump to